@@ -7,6 +7,7 @@ import (
 	sq "github.com/Masterminds/squirrel"
 	"github.com/danvergara/dblab/pkg/command"
 	"github.com/danvergara/dblab/pkg/connection"
+	"github.com/danvergara/dblab/pkg/pagination"
 	"github.com/jmoiron/sqlx"
 
 	// mysql driver.
@@ -19,8 +20,10 @@ import (
 
 // Client is used to store the pool of db connection.
 type Client struct {
-	db     *sqlx.DB
-	driver string
+	db                *sqlx.DB
+	driver            string
+	paginationManager *pagination.Manager
+	limit             int
 }
 
 // New return an instance of the client.
@@ -38,8 +41,16 @@ func New(opts command.Options) (*Client, error) {
 	c := Client{
 		db:     db,
 		driver: opts.Driver,
+		limit:  opts.Limit,
 	}
 
+	pm, err := pagination.New(c.limit, 0, "")
+	if err != nil {
+		return nil, err
+	}
+
+	c.paginationManager = pm
+
 	return &c, nil
 }
 
@@ -85,6 +96,80 @@ func (c *Client) Query(q string, args ...interface{}) ([][]string, []string, err
 	return resultSet, columnNames, nil
 }
 
+// Table represents a SQL table.
+type Table struct {
+	Rows    [][]string
+	Columns []string
+}
+
+// Metadata sums up the most relevant data from a table.
+type Metadata struct {
+	TableContent Table
+	Structure    Table
+	Constraints  Table
+	Indexes      Table
+	TotalPages   int
+}
+
+// Metadata retunrs the most relevant data from a given table.
+func (c *Client) Metadata(tableName string) (*Metadata, error) {
+	count, err := c.tableCount(tableName)
+	if err != nil {
+		return nil, err
+	}
+
+	pm, err := pagination.New(c.limit, count, tableName)
+	if err != nil {
+		return nil, err
+	}
+
+	c.paginationManager = pm
+
+	pages := c.paginationManager.TotalPages()
+
+	tcRows, tcColumns, err := c.tableContent(tableName)
+	if err != nil {
+		return nil, err
+	}
+
+	sRows, sColumns, err := c.tableStructure(tableName)
+	if err != nil {
+		return nil, err
+	}
+
+	cRows, cColumns, err := c.constraints(tableName)
+	if err != nil {
+		return nil, err
+	}
+
+	iRows, iColumns, err := c.indexes(tableName)
+	if err != nil {
+		return nil, err
+	}
+
+	m := Metadata{
+		TableContent: Table{
+			Rows:    tcRows,
+			Columns: tcColumns,
+		},
+		Structure: Table{
+			Rows:    sRows,
+			Columns: sColumns,
+		},
+		Constraints: Table{
+			Rows:    cRows,
+			Columns: cColumns,
+		},
+		Indexes: Table{
+			Rows:    iRows,
+			Columns: iColumns,
+		},
+		TotalPages: pages,
+	}
+
+	return &m, nil
+}
+
 // ShowTables list all the tables in the database on the tables panel.
 func (c *Client) ShowTables() ([]string, error) {
 	var query string
@@ -133,21 +218,104 @@ func (c *Client) ShowTables() ([]string, error) {
 	return tables, nil
 }
 
+// NextPage returns the next page of the given table, based off the limit and the offsite.
+func (c *Client) NextPage() (*Table, int, error) {
+	if err := c.paginationManager.NextPage(); err != nil {
+		return nil, 0, err
+	}
+
+	r, col, err := c.tableContent(c.paginationManager.CurrentTable())
+	if err != nil {
+		return nil, 0, err
+	}
+
+	t := Table{
+		Rows:    r,
+		Columns: col,
+	}
+
+	page := c.paginationManager.CurrentPage()
+
+	return &t, page, nil
+}
+
+// PreviousPage returns the next page of the given table, based off the limit and the offsite.
+func (c *Client) PreviousPage() (*Table, int, error) {
+	if err := c.paginationManager.PreviousPage(); err != nil {
+		return nil, 0, err
+	}
+
+	r, col, err := c.tableContent(c.paginationManager.CurrentTable())
+	if err != nil {
+		return nil, 0, err
+	}
+
+	t := Table{
+		Rows:    r,
+		Columns: col,
+	}
+
+	page := c.paginationManager.CurrentPage()
+
+	return &t, page, nil
+}
+
+// ResetPagination resets the paginationManager field.
+func (c *Client) ResetPagination() error {
+	pm, err := pagination.New(c.limit, 0, "")
+	if err != nil {
+		return err
+	}
+
+	c.paginationManager = pm
+	return nil
+}
+
+// DB Return the db attribute.
+func (c *Client) DB() *sqlx.DB {
+	return c.db
+}
+
+// Driver returns the driver of the database.
+func (c *Client) Driver() string {
+	return c.driver
+}
+
 // TableContent returns all the rows of a table.
-func (c *Client) TableContent(tableName string) ([][]string, []string, error) {
+func (c *Client) tableContent(tableName string) ([][]string, []string, error) {
 	var query string
 
 	if c.driver == "postgres" || c.driver == "postgresql" {
-		query = fmt.Sprintf("SELECT * FROM public.%s LIMIT 100;", tableName)
+		query = fmt.Sprintf("SELECT * FROM public.%s LIMIT %d OFFSET %d;", tableName, c.paginationManager.Limit(), c.paginationManager.Offset())
 	} else {
-		query = fmt.Sprintf("SELECT * FROM %s LIMIT 100;", tableName)
+		query = fmt.Sprintf("SELECT * FROM %s LIMIT %d OFFSET %d;", tableName, c.paginationManager.Limit(), c.paginationManager.Offset())
 	}
 
 	return c.Query(query)
 }
 
-// TableStructure returns the structure of the table columns.
-func (c *Client) TableStructure(tableName string) ([][]string, []string, error) {
+// tableCount returns the count of a given table.
+func (c *Client) tableCount(tableName string) (int, error) {
+	var (
+		query string
+		count int
+	)
+
+	if c.driver == "postgres" || c.driver == "postgresql" {
+		query = fmt.Sprintf("SELECT COUNT(*) FROM public.%s;", tableName)
+	} else {
+		query = fmt.Sprintf("SELECT COUNT(*) FROM %s;", tableName)
+	}
+
+	if err := c.db.Get(&count, query); err != nil {
+		return 0, err
+	}
+
+	return count, nil
+}
+
+// tableStructure returns the structure of the table columns.
+func (c *Client) tableStructure(tableName string) ([][]string, []string, error) {
 	var query string
 
 	switch c.driver {
@@ -192,8 +360,8 @@ func (c *Client) TableStructure(tableName string) ([][]string, []string, error)
 	}
 }
 
-// Constraints returns the resultet of from information_schema.table_constraints.
-func (c *Client) Constraints(tableName string) ([][]string, []string, error) {
+// constraints returns the resultet of from information_schema.table_constraints.
+func (c *Client) constraints(tableName string) ([][]string, []string, error) {
 	var (
 		query sq.SelectBuilder
 		sql   string
@@ -231,8 +399,8 @@ func (c *Client) Constraints(tableName string) ([][]string, []string, error) {
 	return c.Query(sql, tableName)
 }
 
-// Indexes returns a resulset with the information of the indexes given a table name.
-func (c *Client) Indexes(tableName string) ([][]string, []string, error) {
+// indexes returns a resulset with the information of the indexes given a table name.
+func (c *Client) indexes(tableName string) ([][]string, []string, error) {
 	var query string
 
 	switch c.driver {
@@ -252,13 +420,3 @@ func (c *Client) Indexes(tableName string) ([][]string, []string, error) {
 		return nil, nil, errors.New("not supported driver")
 	}
 }
-
-// DB Return the db attribute.
-func (c *Client) DB() *sqlx.DB {
-	return c.db
-}
-
-// Driver returns the driver of the database.
-func (c *Client) Driver() string {
-	return c.driver
-}
